@@ -1,6 +1,6 @@
 import ff1
 import ff3
-from FPE import Mode
+import Mode
 
 def encrypt(plainNumerals,key,tweak,radix,mode):
 	if mode == Mode.FF1:
